@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright (C) 2018-2024 Univention GmbH
+# Copyright (C) 2018-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -44,6 +44,7 @@ fi
 VERSION="52"  # we don't put 51 here because the upgrade should look like upgrading to UCS 5.2
 VERSION_NAME="5.2"
 MIN_VERSION="5.0-7"
+MIN_VERSION_SYSTEM="5.2-1-39"
 
 # shellcheck disable=SC2034
 updateLogDir="/var/univention-backup/update-to-${UPDATE_NEXT_VERSION:-$VERSION_NAME}"
@@ -125,7 +126,7 @@ update_check_slapd_on_member () {
 update_check_ldap_schema () {
 	[ -x /usr/sbin/slapschema ] ||
 		return 0
-	/usr/sbin/slapschema -f /etc/ldap/slapd.conf 1>&2 &&
+	/usr/sbin/slapschema -f /etc/ldap/slapd.conf -c 1>&2 &&
 		return 0
 
 	echo "	There is a problem with the LDAP schema on this system."
@@ -164,6 +165,26 @@ update_check_ldap_connection () {
 	return 1
 }
 
+
+# Bug #58045 Loading the database from the LDIF dump failed - could not parse entry (line=xxx)
+# Note: This check should be enabled only for major and minor updates
+_disabled_verify_translog_schema () {
+  local var="update$VERSION/verify_translog_schema"
+  ignore_check "$var" && return 100
+  if [ "$server_role" != "domaincontroller_master" ] && [ "$server_role" != "domaincontroller_backup" ];
+  then
+    return 0
+  fi
+  if slapcat -f /etc/ldap/slapd.conf  -n 3 | slapadd -f /etc/ldap/slapd.conf -n 3 -u; then
+    return 0
+  fi
+  echo "	There is a problem with the translog schema on this system."
+  echo "	Please check $UPDATER_LOG or run 'slapcat -f /etc/ldap/slapd.conf  -n 3 | slapadd -f /etc/ldap/slapd.conf -n 3 -u' manually."
+  echo "	Please see <https://help.univention.com/t/23981> for more information."
+  return 1
+}
+
+
 _migrate_openldap_bdb_failed () {
 	local msg="$1"
 	local revert="${2:-false}"
@@ -244,7 +265,7 @@ update_check_role_package_removed () {
 
 # Bug #56134 Bug #56651 Bug #56367 Bug #52048 Bug #56765
 # Admin must agree to remove these:
-# Issue univention/ucs#1885
+# Issue univention/dev/ucs#1885
 #  we removed univentionSAMLServiceProvider, univentionSAMLIdpConfig and
 #  univentionOIDCService, we remove these objects in check_keycloak_migration
 #  but as we support mixed environments (5.0/5.2) we have to support these
@@ -426,7 +447,7 @@ update_check_disk_space () {
 		fi
 	done <<__PART__
 /var/cache/apt/archives	4000000	4000 MB
-/boot	100000	100 MB
+/boot	200000	200 MB
 /	4000000	4000 MB
 __PART__
 	echo
@@ -503,6 +524,32 @@ if blocking_computers or blocking_objects:
     exit(1)'
 }
 
+update_check_ucsschool () {
+  local ucs_school_umc_exam_master_version="$(dpkg-query -W -f='${db:Status-Status} ${Version}' ucs-school-umc-exam-master 2>/dev/null | grep 'installed' | awk '{print $2}')"
+  if [ -n "$ucs_school_umc_exam_master_version" ] && dpkg --compare-versions "$ucs_school_umc_exam_master_version" le "12.0.4"; then
+    echo "	You have the package ucs-school-umc-exam-master version $ucs_school_umc_exam_master_version installed."
+    echo "	This package is provided by the app 'UCS@school' version 5.2 v2 or older and currently is incompatible with UCS 5.2-2."
+    echo "	Please wait for the next version of UCS@school to be released."
+    return 1
+  fi
+}
+
+# Bug 58164: Upgrade to UCS 5.2: LDAP Database is empty - Loading the domain database from the LDIF dump failed - attribute type undefined
+_disabled_cool_solutions () {
+  ! is_ucr_true repository/online/component/cool-solutions && return 0
+  if [ "$repository_online_component_cool_solutions_version" = "current" ]; then
+    return 0
+  fi
+  echo "	Cool Solutions component is not correctly setup"
+  echo "	Setting repository/online/component/cool-solutions/version to current."
+  ucr set repository/online/component/cool-solutions/version=current 2>>"$UPDATER_LOG" 3>>"$UPDATER_LOG" 1>>"$UPDATER_LOG"
+  ucr unset " repository/online/component/cool-solutions/version" 2>>"$UPDATER_LOG" 3>>"$UPDATER_LOG" 1>>"$UPDATER_LOG"
+  echo "	Setting repository/online/component/cool-solutions/unmaintained to yes."
+  ucr set repository/online/component/cool-solutions/unmaintained=yes 2>>"$UPDATER_LOG" 3>>"$UPDATER_LOG" 1>>"$UPDATER_LOG"
+  ucr unset " repository/online/component/cool-solutions/unmaintained" 2>>"$UPDATER_LOG" 3>>"$UPDATER_LOG" 1>>"$UPDATER_LOG"
+  return 1
+}
+
 checks () {
 	# stderr to log
 	exec 2>>"$UPDATER_LOG"
