@@ -4,7 +4,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-FileCopyrightText: 2024-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Unit test for univention.updater.tools"""
@@ -22,7 +22,7 @@ import univention.updater.tools as U
 UU = U.UniventionUpdater
 
 
-@pytest.fixture()
+@pytest.fixture
 def u(http):
     """Mock UCS updater."""
     http({
