@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2011-2024 Univention GmbH
+# Copyright 2011-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -425,7 +425,7 @@ class Instance(Base):
         count=IntegerSanitizer(default=0),
     )
     @simple_response
-    def updater_log_file(self, job: str, count: int) -> None | float | list[str]:
+    def updater_log_file(self, job: str, count: int) -> float | list[str] | None:
         """
         returns the content of the log file associated with
         the job.
